@@ -163,7 +163,7 @@ class KubeSphereProps:
         :param nodegroup_options: Options to create the Amazon EKS managed nodegroup. Default: - 2x m5.large on-demand instances
         '''
         if isinstance(nodegroup_options, dict):
-            nodegroup_options = NodegroupOptions(**nodegroup_options)
+            nodegroup_options = aws_cdk.aws_eks.NodegroupOptions(**nodegroup_options)
         if __debug__:
             type_hints = typing.get_type_hints(KubeSphereProps.__init__)
             check_type(argname="argument app_store", value=app_store, expected_type=type_hints["app_store"])
